@@ -8,8 +8,9 @@ def main(config: dict) -> dict:
 	# Assets files
 	if config.get('assets_folder'):
 		config['assets_files'] = [clean_path(f"{root}/{f}") for root, _, files in os.walk(config['assets_folder']) for f in files]
-		if config.get('textures_folder'):
-			config['textures_files'] = [path.split(f"{config['textures_folder']}/")[1] for path in config['assets_files'] if path.startswith(config['textures_folder']) and path.endswith(".png")]
+		textures: str = f"{config['assets_folder']}/textures"
+		if os.path.exists(textures):
+			config['textures_files'] = [path.split(f"{textures}/")[1] for path in config['assets_files'] if path.startswith(textures) and path.endswith(".png")]
 
 	# Datapack related constants
 	config['datapack_name_simple'] = "".join([c for c in config['datapack_name'] if c.isalnum()])		# Simplified version of the datapack name, used for paths
