@@ -117,7 +117,7 @@ class EquipmentsConfig():
 		return {key: value for key, value in self.attributes.items() if key not in NOT_ON_ARMOR}
 
 # UUIDs utils
-def format_attributes(config: dict, attributes: str, slot: str, attr_config: dict = {}) -> list[dict]:
+def format_attributes(config: dict, attributes: dict, slot: str, attr_config: dict = {}) -> list[dict]:
 	""" Returns generated attribute_modifiers key for an item (adds up attributes and config) """
 	# Get attributes from config
 	attribute_modifiers = []
@@ -164,13 +164,13 @@ def generate_everything_about_this_material(config: dict, database: dict[str, di
 		tools_attributes = equipments_config.get_tools_attributes()
 
 	# Get ore color (for armor dye and other stuff)
-	color = None
+	color: int = 0
 	if f"{material_base}_chestplate.png" in config['textures_files']:
-		color = Image.open(f"{config['textures_folder']}/{material_base}_chestplate.png")
-		color = list(color.getdata())										# Get image (1D Array)
-		color = [(r,g,b) for (r,g,b,a) in color if a > 0]					# Get all colors that are not transparent
-		color = [sum(x) / len(color) for x in zip(*color)]					# Get the average color
-		color = int(color[0]) << 16 | int(color[1]) << 8 | int(color[2])	# Convert to int (Minecraft format: Red<<16 + Green<<8 + Blue)
+		color_image: Image.Image = Image.open(f"{config['assets_folder']}/textures/{material_base}_chestplate.png")
+		color_list: list = list(color_image.getdata())									# Get image (1D Array)
+		color_list = [(r,g,b) for (r,g,b,a) in color_list if a > 0]						# Get all colors that are not transparent
+		color_list = [sum(x) / len(color_list) for x in zip(*color_list)]				# Get the average color
+		color = int(color_list[0]) << 16 | int(color_list[1]) << 8 | int(color_list[2])	# Convert to int (Minecraft format: Red<<16 + Green<<8 + Blue)
 
 	# Placeables (ore, deepslate_ore, block, raw_block)
 	for block in [f"{material_base}_block", f"{material_base}_ore", f"deepslate_{material_base}_ore", f"raw_{material_base}_block"]:
@@ -554,10 +554,12 @@ def add_private_custom_data_for_namespace(config: dict, database: dict[str, dict
 		if not data.get("custom_data"):
 			data["custom_data"] = {}
 		if not is_external:
-			data["custom_data"][config['namespace']] = {item: True}
-		else:
+			ns, id = config['namespace'], item
+		elif ":" in item:
 			ns, id = item.split(":")
-			data["custom_data"][ns] = {id: True}
+		if not data["custom_data"].get(ns):
+			data["custom_data"][ns] = {}
+		data["custom_data"][ns][id] = True
 	return
 
 # Smithed ignore convention
